@@ -459,7 +459,10 @@ class BeamTrace():
                 z_start = self.comp_dict[key]['start_location']
                 z_end = self.comp_dict[key]['end_location']
 
-                z_start_index = np.argwhere(self.zz > z_start)[0,0]
+                print(key)
+                print(z_start)
+                print(self.zz[-1])
+                z_start_index = np.argwhere(self.zz >= z_start)[0,0]
                 z_end_index = np.argwhere(self.zz <= z_end)[-1,0]
 
                 try:
